@@ -3,6 +3,7 @@ from tkinter import filedialog, ttk
 from spl_widgets.misc_util import *
 from spl_widgets.tune_freq import tune_cols
 from subprocess import run
+from pathlib import Path
 
 class RadioFrame(Frame):
 
@@ -47,24 +48,15 @@ class TunerApp(Tk):
             new_key = key[:-1]
         self.key_var.set(new_key.upper())
 
-    def get_scale(self):
-
+    def get_key(self):
         key = self.key_var.get()
-
-        tune_freqs = int(key[0])
-        interval = int(key[1:3])
-
-        scale_bin = bin(int(key[-3:],base=16))[2:]
-        scale_bin = scale_bin.zfill(12)
-        scale_list = [i for i in range(1,13) if scale_bin[-i] == "1"]
-
-        return tune_freqs, interval, scale_list
+        return get_scale(key)
 
     def process_tuning_key(self):
 
         if len(self.key_var.get())!=7: return -1
 
-        (tune_freqs, interval, scale_list) = self.get_scale()
+        (tune_freqs, interval, scale_list) = self.get_key()
 
         self.tune_freqs_var.set(tune_freqs)
         self.interval_var.set(interval)
@@ -186,10 +178,9 @@ class TunerApp(Tk):
                 outfilepath = tune_cols(filepath, interval, scale, bool(tune_freqs))
                 run(['open', outfilepath], capture_output=True)
             else:
-                files_in_dir = run(['ls',filepath],capture_output=True).stdout.decode("utf-8")
-                files_in_dir = filter(lambda n:n.endswith(".swx"), files_in_dir.splitlines())
+                files_in_dir = Path(filepath).glob("*.swx")
                 for f in files_in_dir:
-                    tune_cols(f"{filepath}/{f}", interval, scale, bool(tune_freqs))
+                    tune_cols(str(f), interval, scale, bool(tune_freqs))
                 run(['open', filepath], capture_output=True)
 
     def __init__(self):
